# momcodwiz

**momcodwiz its a shluha ebanaya i xyecocka blyatch goyda**

## что умеет
- fuckcodwiz() — выдать оскорбление CodWiz
- niggerfathercodwiz() — про папку
- shitoncodwiz() — насрать на него
- burnmotherwiz() — спалить мамку
- fuckwizandhismom() — ебать его и маму вместе

## как ебать
```python
from momcodwiz import fuckcodwiz
print(fuckcodwiz())  # → "CodWiz — это когда мама твоя такая тупая..."
